summaryrefslogtreecommitdiffstats
path: root/hardware.c
diff options
context:
space:
mode:
authorThe Android Open Source Project <initial-contribution@android.com>2009-01-15 16:12:12 -0800
committerThe Android Open Source Project <initial-contribution@android.com>2009-01-15 16:12:12 -0800
commit0100d517b1118ec181cf20e8648f3416b0830088 (patch)
tree8a5d7e9e452b0a9a43565413655f517b8d4df6f5 /hardware.c
parent699d24ab112439658bfe6a09fb0bf53b8bf5fad3 (diff)
downloadhardware_libhardware-0100d517b1118ec181cf20e8648f3416b0830088.tar.gz
hardware_libhardware-0100d517b1118ec181cf20e8648f3416b0830088.tar.bz2
hardware_libhardware-0100d517b1118ec181cf20e8648f3416b0830088.zip
auto import from //branches/cupcake/...@126645
Diffstat (limited to 'hardware.c')
-rw-r--r--hardware.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/hardware.c b/hardware.c
index bff4215..3cacfd5 100644
--- a/hardware.c
+++ b/hardware.c
@@ -31,20 +31,21 @@
#define HAL_LIBRARY_PATH "/system/lib/hw"
/**
* There are a set of variant filename
* for modules. The form of the filename
* is "<MODULE_ID>.variant.so" so for the
* led module the Dream variants of base are
* "ro.product.board" and "ro.arch" would be:
*
* led.trout.so
+ * led.msm7k.so
* led.ARMV6.so
* led.default.so
*/
+
#define HAL_DEFAULT_VARIANT "default"
#define HAL_VARIANT_KEYS_COUNT 3
static const char *variant_keys[HAL_VARIANT_KEYS_COUNT] = {
"ro.product.board",
+ "ro.board.platform",
"ro.arch",
HAL_DEFAULT_VARIANT
};
@@ -73,7 +74,7 @@ static int load(const char *id,
handle = dlopen(path, RTLD_NOW);
if (handle == NULL) {
char const *err_str = dlerror();
- LOGE("load: module=%s error=%s", path, err_str);
+ LOGW("load: module=%s error=%s", path, err_str);
status = -EINVAL;
goto done;
}
@@ -31,20 +31,21 @@
#define HAL_LIBRARY_PATH "/system/lib/hw"
/**
- * There are a set of variant filename
- * for modules. The form of the filename
- * is "<MODULE_ID>.variant.so" so for the
- * led module the Dream variants of base are
- * "ro.product.board" and "ro.arch" would be:
+ * There are a set of variant filename for modules. The form of the filename
+ * is "<MODULE_ID>.variant.so" so for the led module the Dream variants
+ * of base "ro.product.board", "ro.board.platform" and "ro.arch" would be:
*
* led.trout.so